@@ -1,7 +1,7 @@
 #encoding:utf-8
 from django import forms
 
-import autocomplete_light
+from dal import autocomplete
 
 from microsip_web.apps.ventas.models import *
 from django.contrib.auth.models import User
