@@ -14,7 +14,7 @@ class GrupoLineasBase(models.Model):
         abstract  = True
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.nombre
         
     def save(self, *args, **kwargs):    
@@ -37,7 +37,7 @@ class LineaArticulosBase(models.Model):
         abstract  = True
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.nombre
         
     def save(self, *args, **kwargs):    
@@ -128,7 +128,7 @@ class ArticuloClaveRolBase(models.Model):
         abstract  = True
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.nombre
 
 class ArticuloClaveBase(models.Model):
@@ -142,7 +142,7 @@ class ArticuloClaveBase(models.Model):
         abstract  = True
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.clave
 
     def save(self, *args, **kwargs):    
@@ -166,7 +166,7 @@ class ArticuloPrecioBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.id
 
     def save(self, *args, **kwargs):    
@@ -189,7 +189,7 @@ class AlmacenBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return self.nombre
 
 class PrecioEmpresaBase(models.Model):
@@ -203,7 +203,7 @@ class PrecioEmpresaBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.nombre
 
     def save(self, *args, **kwargs):    
@@ -228,7 +228,7 @@ class ArticuloDiscretoBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.clave
 
 class ArticuloDiscretoExistenciaBase(models.Model):
@@ -243,7 +243,7 @@ class ArticuloDiscretoExistenciaBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % self.id
 
 class ArticuloNivelBase(models.Model):
@@ -261,7 +261,7 @@ class ArticuloNivelBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s-%s' % (self.id, self.localizacion)
 
 class ClasificadoresBase(models.Model):
@@ -283,7 +283,7 @@ class ClasificadoresBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % (self.nombre)
 
 class ClasificadoresValoresBase(models.Model):
@@ -298,7 +298,7 @@ class ClasificadoresValoresBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % (self.valor)
     
 class ElementosClasificadoresBase(models.Model):
@@ -312,8 +312,22 @@ class ElementosClasificadoresBase(models.Model):
         managed= False
         app_label='models_base'
 
-    def __unicode__(self):
+    def __str__( self ):
         return u'%s' % (self.valor_clasificador)
+
+class LibreArticuloBase(models.Model):
+    articulo_id=models.IntegerField(primary_key=True, db_column='ARTICULO_ID')
+    no_serie=models.CharField(max_length=20, db_column="NO_SERIE")
+    fecha_compra=models.DateTimeField(db_column='FECHA_COMPRA', blank=True, null=True)
+    costo=models.IntegerField(null=True, db_column='COSTO')
+    refaccion=models.IntegerField(null=True, db_column='REFACCION')
+    flete=models.IntegerField(null=True, db_column='FLETE')
+    class Meta:
+        db_table = u'LIBRES_ARTICULOS'
+        abstract = True
+
+    def __str__( self ):
+        return u'%s' % (self.articulo_id)
         
     
 
